@@ -7,7 +7,8 @@
 # For further information on the license, see the LICENSE.txt file        #
 # For further information please visit http://www.aiida.net               #
 ###########################################################################
-
+# pylint: disable=invalid-name
+"""Database migration."""
 from django.db import migrations
 from aiida.backends.djsite.db.migrations import upgrade_schema_version
 
@@ -16,6 +17,7 @@ DOWN_REVISION = '1.0.16'
 
 
 class Migration(migrations.Migration):
+    """Database migration."""
 
     dependencies = [
         ('db', '0016_code_sub_class_of_data'),
