@@ -47,7 +47,7 @@ def json_serializer(obj):
     if isinstance(obj, (datetime, date)):
         return obj.isoformat()
 
-    raise TypeError('Type %s not serializable' % type(obj))
+    raise TypeError(f'Type {type(obj)} not serializable')
 
 
 def export_workflow_data(connection):
@@ -91,7 +91,7 @@ def export_workflow_data(connection):
 
     # If delete_on_close is False, we are running for the user and add additional message of file location
     if not delete_on_close:
-        echo.echo_info('Exported workflow data to {}'.format(filename))
+        echo.echo_info(f'Exported workflow data to {filename}')
 
 
 def upgrade():
