@@ -23,7 +23,7 @@ class ConfigOptionParamType(click.types.StringParamType):
         from aiida.manage.configuration.options import get_option, get_option_names
 
         if value not in get_option_names():
-            raise click.BadParameter('{} is not a valid configuration option'.format(value))
+            raise click.BadParameter(f'{value} is not a valid configuration option')
 
         return get_option(value)
 
