@@ -47,7 +47,7 @@ def upload_calculation(node, transport, calc_info, folder, inputs=None, dry_run=
     # chance to perform the state transition. Upon reloading this calculation, it will re-attempt the upload.
     link_label = 'remote_folder'
     if node.get_outgoing(RemoteData, link_label_filter=link_label).first():
-        execlogger.warning('CalcJobNode<{}> already has a `{}` output: skipping upload'.format(node.pk, link_label))
+        execlogger.warning(f'CalcJobNode<{node.pk}> already has a `{link_label}` output: skipping upload')
         return calc_info
 
     computer = node.computer
@@ -118,9 +118,7 @@ def upload_calculation(node, transport, calc_info, folder, inputs=None, dry_run=
             path_lost_found = os.path.join(remote_working_directory, REMOTE_WORK_DIRECTORY_LOST_FOUND)
             path_target = os.path.join(path_lost_found, calc_info.uuid)
             logger.warning(
-                'tried to create path {} but it already exists, moving the entire folder to {}'.format(
-                    path_existing, path_target
-                )
+                f'tried to create path {path_existing} but it already exists, moving the entire folder to {path_target}'
             )
 
             # Make sure the lost+found directory exists, then copy the existing folder there and delete the original
@@ -162,7 +160,7 @@ def upload_calculation(node, transport, calc_info, folder, inputs=None, dry_run=
     provenance_exclude_list = calc_info.provenance_exclude_list or []
 
     for uuid, filename, target in local_copy_list:
-        logger.debug('[submission of calculation {}] copying local file/folder to {}'.format(node.uuid, target))
+        logger.debug(f'[submission of calculation {node.uuid}] copying local file/folder to {target}')
 
         def find_data_node(inputs, uuid):
             """Find and return the node with the given UUID from a nested mapping of input nodes.
@@ -190,7 +188,7 @@ def upload_calculation(node, transport, calc_info, folder, inputs=None, dry_run=
             data_node = find_data_node(inputs, uuid)
 
         if data_node is None:
-            logger.warning('failed to load Node<{}> specified in the `local_copy_list`'.format(uuid))
+            logger.warning(f'failed to load Node<{uuid}> specified in the `local_copy_list`')
         else:
             dirname = os.path.dirname(target)
             if dirname:
@@ -203,7 +201,7 @@ def upload_calculation(node, transport, calc_info, folder, inputs=None, dry_run=
     # In a dry_run, the working directory is the raw input folder, which will already contain these resources
     if not dry_run:
         for filename in folder.get_content_list():
-            logger.debug('[submission of calculation {}] copying file/folder {}...'.format(node.pk, filename))
+            logger.debug(f'[submission of calculation {node.pk}] copying file/folder {filename}...')
             transport.put(folder.get_abs_path(filename), filename)
 
         for (remote_computer_uuid, remote_abs_path, dest_rel_path) in remote_copy_list:
@@ -244,8 +242,7 @@ def upload_calculation(node, transport, calc_info, folder, inputs=None, dry_run=
                     raise
             else:
                 raise IOError(
-                    'It is not possible to create a symlink between two different machines for '
-                    'calculation {}'.format(node.pk)
+                    f'It is not possible to create a symlink between two different machines for calculation {node.pk}'
                 )
     else:
 
@@ -339,8 +336,8 @@ def retrieve_calculation(calculation, transport, retrieved_temporary_folder):
     logger_extra = get_dblogger_extra(calculation)
     workdir = calculation.get_remote_workdir()
 
-    execlogger.debug('Retrieving calc {}'.format(calculation.pk), extra=logger_extra)
-    execlogger.debug('[retrieval of calc {}] chdir {}'.format(calculation.pk, workdir), extra=logger_extra)
+    execlogger.debug(f'Retrieving calc {calculation.pk}', extra=logger_extra)
+    execlogger.debug(f'[retrieval of calc {calculation.pk}] chdir {workdir}', extra=logger_extra)
 
     # If the calculation already has a `retrieved` folder, simply return. The retrieval was apparently already completed
     # before, which can happen if the daemon is restarted and it shuts down after retrieving but before getting the
@@ -348,7 +345,7 @@ def retrieve_calculation(calculation, transport, retrieved_temporary_folder):
     link_label = calculation.link_label_retrieved
     if calculation.get_outgoing(FolderData, link_label_filter=link_label).first():
         execlogger.warning(
-            'CalcJobNode<{}> already has a `{}` output folder: skipping retrieval'.format(calculation.pk, link_label)
+            f'CalcJobNode<{calculation.pk}> already has a `{link_label}` output folder: skipping retrieval'
         )
         return
 
@@ -381,15 +378,13 @@ def retrieve_calculation(calculation, transport, retrieved_temporary_folder):
             # Log the files that were retrieved in the temporary folder
             for filename in os.listdir(retrieved_temporary_folder):
                 execlogger.debug(
-                    "[retrieval of calc {}] Retrieved temporary file or folder '{}'".format(calculation.pk, filename),
+                    f"[retrieval of calc {calculation.pk}] Retrieved temporary file or folder '{filename}'",
                     extra=logger_extra
                 )
 
         # Store everything
         execlogger.debug(
-            '[retrieval of calc {}] '
-            'Storing retrieved_files={}'.format(calculation.pk, retrieved_files.pk),
-            extra=logger_extra
+            f'[retrieval of calc {calculation.pk}] Storing retrieved_files={retrieved_files.pk}', extra=logger_extra
         )
         retrieved_files.store()
 
@@ -423,7 +418,7 @@ def kill_calculation(calculation, transport):
 
         # If the job is returned it is still running and the kill really failed, so we raise
         if job is not None and job.job_state != JobState.DONE:
-            raise exceptions.RemoteOperationError('scheduler.kill({}) was unsuccessful'.format(job_id))
+            raise exceptions.RemoteOperationError(f'scheduler.kill({job_id}) was unsuccessful')
         else:
             execlogger.warning('scheduler.kill() failed but job<{%s}> no longer seems to be running regardless', job_id)
 
@@ -455,10 +450,7 @@ def _retrieve_singlefiles(job, transport, folder, retrieve_file_list, logger_ext
         singlefiles.append(singlefile)
 
     for fil in singlefiles:
-        execlogger.debug(
-            '[retrieval of calc {}] '
-            'Storing retrieved_singlefile={}'.format(job.pk, fil.pk), extra=logger_extra
-        )
+        execlogger.debug(f'[retrieval of calc {job.pk}] Storing retrieved_singlefile={fil.pk}', extra=logger_extra)
         fil.store()
 
 
@@ -514,7 +506,5 @@ def retrieve_files_from_list(calculation, transport, folder, retrieve_list):
                 local_names = [os.path.split(item)[1]]
 
         for rem, loc in zip(remote_names, local_names):
-            transport.logger.debug(
-                "[retrieval of calc {}] Trying to retrieve remote item '{}'".format(calculation.pk, rem)
-            )
+            transport.logger.debug(f"[retrieval of calc {calculation.pk}] Trying to retrieve remote item '{rem}'")
             transport.get(rem, os.path.join(folder, loc), ignore_nonexisting=True)
