@@ -61,11 +61,11 @@ class PbsproScheduler(PbsBaseClass):
 
         return_lines = []
 
-        select_string = 'select={}'.format(num_machines)
+        select_string = f'select={num_machines}'
         if num_mpiprocs_per_machine:
-            select_string += ':mpiprocs={}'.format(num_mpiprocs_per_machine)
+            select_string += f':mpiprocs={num_mpiprocs_per_machine}'
         if num_cores_per_machine:
-            select_string += ':ppn={}'.format(num_cores_per_machine)
+            select_string += f':ppn={num_cores_per_machine}'
 
         if max_wallclock_seconds is not None:
             try:
@@ -82,7 +82,7 @@ class PbsproScheduler(PbsBaseClass):
             tot_minutes = tot_secs % 3600
             minutes = tot_minutes // 60
             seconds = tot_minutes % 60
-            return_lines.append('#PBS -l walltime={:02d}:{:02d}:{:02d}'.format(hours, minutes, seconds))
+            return_lines.append(f'#PBS -l walltime={hours:02d}:{minutes:02d}:{seconds:02d}')
 
         if max_memory_kb:
             try:
@@ -95,7 +95,7 @@ class PbsproScheduler(PbsBaseClass):
                     "a positive integer (in kB)! It is instead '{}'"
                     ''.format((max_memory_kb))
                 )
-            select_string += ':mem={}kb'.format(virtual_memory_kb)
+            select_string += f':mem={virtual_memory_kb}kb'
 
-        return_lines.append('#PBS -l {}'.format(select_string))
+        return_lines.append(f'#PBS -l {select_string}')
         return return_lines
